@@ -4,6 +4,7 @@ from __future__ import absolute_import
 
 from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
 from bitmovin_api_sdk.common.poscheck import poscheck_except
+from bitmovin_api_sdk.encoding.configurations.subtitles.dvb_subtitle.dvb_subtitle_api import DvbSubtitleApi
 from bitmovin_api_sdk.encoding.configurations.subtitles.webvtt.webvtt_api import WebvttApi
 
 
@@ -19,6 +20,13 @@ class SubtitlesApi(BaseApi):
             logger=logger
         )
 
+        self.dvb_subtitle = DvbSubtitleApi(
+            api_key=api_key,
+            tenant_org_id=tenant_org_id,
+            base_url=base_url,
+            logger=logger
+        )
+
         self.webvtt = WebvttApi(
             api_key=api_key,
             tenant_org_id=tenant_org_id,
